@@ -251,7 +251,7 @@ class TerminalBuildScript(buildscript.BuildScript):
 
     def handle_error(self, module, phase, nextphase, error, altphases):
         '''handle error during build'''
-        summary = _('error during phase %(phase)s of %(module)s') % {
+        summary = _('Error during phase %(phase)s of %(module)s') % {
             'phase': phase, 'module':module.name}
         try:
             error_message = error.args[0]
@@ -278,18 +278,22 @@ class TerminalBuildScript(buildscript.BuildScript):
             return 'fail'
         while True:
             print
-            uprint(_('  [1] rerun phase %s') % phase)
+            uprint('  [1] %s' % _('Rerun phase %s') % phase)
             if nextphase:
-                uprint(_('  [2] ignore error and continue to %s') % nextphase)
+                uprint('  [2] %s' % _('Ignore error and continue to %s') % nextphase)
             else:
-                uprint(_('  [2] ignore error and continue to next module'))
-            uprint(_('  [3] give up on module'))
-            uprint(_('  [4] start shell'))
-            uprint(_('  [5] reload configuration'))
+                uprint('  [2] %s' % _('Ignore error and continue to next module'))
+            uprint('  [3] %s' % _('Give up on module'))
+            uprint('  [4] %s' % _('Start shell'))
+            uprint('  [5] %s' % _('Reload configuration'))
             nb_options = i = 6
-            for altphase in (altphases or []):
-                uprint(_('  [%d] go to phase %s') % (i, altphase))
-                i = i + 1
+            for altphase in altphases:
+                try:
+                    altphase_label = _(getattr(getattr(module, 'do_' + altphase), 'label'))
+                except AttributeError:
+                    altphase_label = altphase
+                uprint('  [%d] %s' % (i, _('Go to phase "%s"') % altphase_label))
+                i += 1
             val = raw_input(uencode(_('choice: ')))
             val = val.strip()
             if val == '1':
@@ -312,9 +316,22 @@ class TerminalBuildScript(buildscript.BuildScript):
             else:
                 try:
                     val = int(val)
-                    return altphases[val - nb_options]
+                    selected_phase = altphases[val - nb_options]
                 except:
                     uprint(_('invalid choice'))
+                    continue
+                try:
+                    needs_confirmation = getattr(
+                            getattr(module, 'do_' + selected_phase), 'needs_confirmation')
+                except AttributeError:
+                    needs_confirmation = False
+                if needs_confirmation:
+                    val = raw_input(uencode(_('Type "yes" to confirm the action: ')))
+                    val = val.strip()
+                    if val.lower() in ('yes', _('Yes')):
+                        return selected_phase
+                    continue
+                return selected_phase
         assert False, 'not reached'
 
 BUILD_SCRIPT = TerminalBuildScript
